# LG M50 cell parameters

Parameters for an LG M50 cell, from the paper

> Chang-Hui Chen, Ferran Brosa Planella, Kieran O’Regan, Dominika Gastol, W. Dhammika Widanage, and Emma Kendrick. "Development of Experimental Techniques for Parameterization of Multi-scale Lithium-ion Battery Models." Submitted for publication (2020).

and references therein. For more information or how to cite please contact Ferran.Brosa-Planella (at) warwick.ac.uk.
